#
# spec file for package tomahawk
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Dominik Schmidt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _tomahawk_major_version 0
%define _tomahawk_minor_version 8
%define _tomahawk_patch_version 99

%define _libtomahawk_soversion %{_tomahawk_major_version}_%{_tomahawk_minor_version}_%{_tomahawk_patch_version}

Name:           tomahawk
Summary:        The social media player
License:        GPL-3.0+
Group:          Productivity/Multimedia/Sound/Players
Version:        0.8.99~git20170808T143449
Release:        lp150.1.30
Source:         tomahawk-%{version}.tar.xz
Source2:        tomahawk.SuSEfirewall2
Source3:        Tomahawk.khotkeys
Source99:       tomahawk-rpmlintrc
# PATCH-FIX-UPSTREAM
Patch1:         0001-Fix-control-reaches-end-of-non-void-function-in-Dele.patch

Url:            http://gettomahawk.com

Requires:       libQt5Sql5-sqlite

BuildRequires:  cmake
BuildRequires:  gcc-c++

# Required deps
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_filesystem-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  attica-qt5-devel >= 0.4.0
BuildRequires:  libechonest-qt5-devel >= 2.3.0
BuildRequires:  libgnutls-devel
BuildRequires:  liblastfm-qt5-devel >= 1.0.1
BuildRequires:  libqca-qt5-devel
BuildRequires:  libqjson-devel
BuildRequires:  lucene++-devel
BuildRequires:  qtkeychain-qt5-devel
BuildRequires:  quazip-qt5-devel
BuildRequires:  sparsehash-devel
BuildRequires:  sqlite3-devel >= 3.6.22
BuildRequires:  taglib-devel >= 1.6.2
BuildRequires:  telepathy-qt5-devel
BuildRequires:  vlc-devel
BuildRequires:  websocketpp-devel
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5UiTools)
BuildRequires:  cmake(Qt5WebKitWidgets)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(Qt5Xml)

# Audio stuff
BuildRequires:  phonon4qt5-devel
Recommends:     phonon4qt5-backend-gstreamer
Recommends:     phonon4qt5-backend-vlc

# Optional deps for additional features
BuildRequires:  libjreen-qt5-devel

# Other
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files

%description
Tomahawk is a multi-source, socially-connected, cross-platform and open-source music player

%package kde
Summary:        KDE integration for Tomahawk
Group:          Productivity/Multimedia/Sound/Players
Requires:       tomahawk = %{version}
Supplements:    packageand(tomahawk:plasma5-workspace)

%description kde
This package makes hotkeys configurable in KDE systemsettings

## Library

%package -n libtomahawk%{_libtomahawk_soversion}
Summary:        Library providing the core functionality of Tomahawk Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       libtomahawk-plugins = %{version}

%description -n libtomahawk%{_libtomahawk_soversion}
Library providing the core functionality of Tomahawk Player a multi-source, socially-connected, cross-platform and open-source music player

%package -n libtomahawk-playdarapi%{_libtomahawk_soversion}
Summary:        Library providing the Playdar API functionality of Tomahawk Player
Group:          Productivity/Multimedia/Sound/Players

%description -n libtomahawk-playdarapi%{_libtomahawk_soversion}
Library providing the Playdar API functionality of Tomahawk Player a multi-source, socially-connected, cross-platform and open-source music player

%package -n libtomahawk-widgets%{_libtomahawk_soversion}
Summary:        Library providing widgets of Tomahawk Player
Group:          Productivity/Multimedia/Sound/Players

%description -n libtomahawk-widgets%{_libtomahawk_soversion}
Library providing the Playdar API functionality of Tomahawk Player a multi-source, socially-connected, cross-platform and open-source music player

%package -n libtomahawk-devel
Summary:        Development files for libtomahawk
Group:          Development/Libraries/C and C++
Requires:       libtomahawk%{_libtomahawk_soversion} = %{version}

%description -n libtomahawk-devel
Library providing widgets of Tomahawk Player a multi-source, socially-connected, cross-platform and open-source music player

## Plugins

%package -n libtomahawk-plugins-telepathy
Summary:        Plugin providing the Telepathy functionality of Tomahawk Player
Group:          Productivity/Multimedia/Sound/Players

%description -n libtomahawk-plugins-telepathy
Plugin providing the Telepathy functionality of Tomahawk Player a multi-source, socially-connected, cross-platform and open-source music player

%package -n libtomahawk-plugins
Summary:        Plugins providing the core functionality of Tomahawk Player
Group:          Productivity/Multimedia/Sound/Players

%description -n libtomahawk-plugins
Plugins providing the core functionality of Tomahawk Player a multi-source, socially-connected, cross-platform and open-source music player

%prep
%setup -q
%patch1 -p1

%build
cmake . \
    -DCMAKE_C_FLAGS="%{optflags}" \
    -DCMAKE_CXX_FLAGS="%{optflags}" \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_INSTALL_LIBEXECDIR=lib \
    -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DCMAKE_VERBOSE_MAKEFILE=ON \
    -DCMAKE_SKIP_RPATH=ON \
    -DWITH_CRASHREPORTER=OFF \
%ifarch %arm ppc ppc64 ppc64le
    -DWITH_BREAKPAD=OFF \
%endif
    -DBUILD_RELEASE=ON

%__make %{?_smp_mflags} || %__make

%install
%make_install

# install firewall service file
%__install -D -m 644 %{_sourcedir}/tomahawk.SuSEfirewall2 \
        %{buildroot}/etc/sysconfig/SuSEfirewall2.d/services/tomahawk

# update desktop file
%suse_update_desktop_file -r tomahawk AudioVideo Player

# install hotkey integration for kde
%__install -D -m 644 %{_sourcedir}/Tomahawk.khotkeys \
        %{buildroot}%{_datadir}/khotkeys/Tomahawk.khotkeys

# currently not "supported" on openSUSE:
%__rm -rf "%{buildroot}%{_datadir}/icons/hicolor/1024x1024"
%__rm -rf "%{buildroot}%{_datadir}/icons/hicolor/512x512"
%__rm -rf "%{buildroot}%{_datadir}/icons/hicolor/128x128-grayscale/"

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n libtomahawk%{_libtomahawk_soversion}
/sbin/ldconfig

%postun -n libtomahawk%{_libtomahawk_soversion}
/sbin/ldconfig

%post -n libtomahawk-playdarapi%{_libtomahawk_soversion}
/sbin/ldconfig

%postun -n libtomahawk-playdarapi%{_libtomahawk_soversion}
/sbin/ldconfig

%post -n libtomahawk-widgets%{_libtomahawk_soversion}
/sbin/ldconfig

%postun -n libtomahawk-widgets%{_libtomahawk_soversion}
/sbin/ldconfig

%files
%defattr(-,root,root,0755)
%doc LICENSE.txt README.md ChangeLog AUTHORS
%{_bindir}/tomahawk

%ifnarch %arm ppc ppc64 ppc64le
# %%{_libexecdir}/tomahawk_crash_reporter
%endif

%{_datadir}/applications/tomahawk.desktop
%{_datadir}/icons/*/*/apps/tomahawk.*

%config /etc/sysconfig/SuSEfirewall2.d/services/tomahawk

%files kde
%defattr(-,root,root,0755)
%dir %{_datadir}/khotkeys/
%{_datadir}/khotkeys/Tomahawk.khotkeys

## Library

%files -n libtomahawk%{_libtomahawk_soversion}
%defattr(-,root,root,0755)
%{_libdir}/libtomahawk.so.*

%files -n libtomahawk-playdarapi%{_libtomahawk_soversion}
%defattr(-,root,root,0755)
%{_libdir}/libtomahawk-playdarapi.so.*

%files -n libtomahawk-widgets%{_libtomahawk_soversion}
%defattr(-,root,root,0755)
%{_libdir}/libtomahawk-widgets.so.*

%files -n libtomahawk-devel
%defattr(-,root,root,0755)
%{_includedir}/libtomahawk/
%{_libdir}/cmake/Tomahawk/
%{_libdir}/libtomahawk.so
%{_libdir}/libtomahawk-playdarapi.so
%{_libdir}/libtomahawk-widgets.so

## Plugins
%files -n libtomahawk-plugins
%defattr(-,root,root,0755)
%{_libdir}/libtomahawk_account_*.so
%{_libdir}/libtomahawk_infoplugin_*.so
%{_libdir}/libtomahawk_viewpage_*.so

%files -n libtomahawk-plugins-telepathy
%defattr(-,root,root,0755)
%{_libdir}/libtomahawk_configstorage_telepathy.so

%changelog
* Sun Dec 10 2017 fabian@ritter-vogt.de
- Update to git master (00f602e)
- Switch to Qt 5
- Remove patch, now upstream:
  * fix-taglib-detection.diff
- Drop libtomahawk-plugins-telepathy-kde, not included anymore
- Add patch to fix warning which rpmlint does not like:
  * 0001-Fix-control-reaches-end-of-non-void-function-in-Dele.patch
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Feb 11 2016 cgiboudeaux@gmx.com
- Add fix-taglib-detection.diff. Use VERSION_LESS to compare versions.
* Wed Apr 15 2015 dev@dominik-schmidt.de
- Update to 0.8.4:
  * Fixed drag & drop issues on sidebar.
  * Fixed starting Tomahawk with a filename as parameter.
  * Update column view when collection changes.
  * (Linux) Don't crash on environments with invalid locales.
- Changes already in 0.8.3:
  * Performance improvements for collection browsing.
  * Improved memory footprint.
  * Show cloud collections above your friends in the sidebar.
  * Keep looking for alternative sources even when we found a perfect match.
  * Fixed crash in network code.
  * Fixed repeat one/all icons.
  * Be more lenient about accepting JSPF and M3U playlists.
  * Improved support for compilation albums.
* Thu Nov 20 2014 dev@dominik-schmidt.de
- Update to 0.8.2
  * Show error message if saving tags failed (instead of crashing)
  * Fixed painting issue on search page.
* Mon Nov 17 2014 dev@dominik-schmidt.de
- Update to 0.8.1:
  * Disabled sorting for stations.
  * Fixed drag & drop behavior in combination with certain resolvers.
  * Fixed infinite scanning recursion.
  * Prevented adding dupes to the collection when scanning.
  * When playing an artist or album, don't give up when the first track
    in list isn't playable.
  * Fixed importing M3U playlists.
  * Sort album grids by artist name.
  * Fixed painting issue on 'More Albums' grid.
  * Fixed crash when editing/saving track tags.
* Tue Nov  4 2014 dev@dominik-schmidt.de
- Update to 0.8.0:
  * Redesigned - Shiny new interface. Simplified. New icons.
  * Added Friend Feed.
  * Many actions now available in context menu - including Favorite
    and Send to a Friend.
  * Drag and drop support for iTunes, Deezer, Beats Music, Rdio,
    Spotify, SoundCloud links (into Tomahawk) for playlists/tracks/
    artists/album links.
  * Support for clicking source icon for currently playing track in
    audio controls to take user to associated page on source's site
  * Added Hatchet plug-in.
  * Added Google Play Music and Beats Music support.
  * Add links to Support site, Bug Reports and Translations to Help menu.
  * Add "What's New" page to display on first launch
    (or until user dismisses it) - also available from Help menu.
  * Changed label from "Resolvers" and "Services" to more generic "Plug-Ins".
  * Clarified some labels, help text and status messages.
  * Changed icon color a bit.
  * Added "Acoustic" and "Electric" songtypes to Stations options.
  * Removed some stale Chart sources.
  * Playback Queue now saves its state across sessions.
  * Queue now moved to sidebar.
  * Added "Inbox" feature, showing incoming song recommendations. Dropping
    a track on a user in the sidebar sends a recommendation to them.
  * You will now be asked whether you want to trust invalid SSL certificates.
  * Improved connecting between Tomahawk peers and support having multiple IPs
    (including IPv6).
  * Removed Top Loved from sidebar.
  * Removed Spotify playlist syncing (we will bring it back in future versions).
  * HTTP(S) streaming is now done by Tomahawk instead of the Phonon backend
    (fixed HTTPS streaming on MacOS).
  * Heavily reduced memory footprint during and after indexing the database.
  * Retina display and DPI scaling fixes.
  * New Collection views. Re-added support for tracklist view of Collection.
  * Added Telepathy support.
  * Plugin refactoring (and .AXE resolver binaries).
  * Removed Twitter due to change in Twitter's API.
  * Removed auto-playlists.
  * Improved error messages.
  * Added basic remote control API.
  * Add support for Opus codec (requires TagLib 1.9).
  * Support rtmp:// streams.
  * Support custom headers in CustomUrlHandler.
  * Fuzzy search indices for JS Resolvers.
  * Add metadata retrieval of HTTP(S) streams in JavaScript resolvers.
- Create subpackages for telepathy (config) plugins, to not pull in the
  whole (kde) telepathy stacks.
- Put libtomahawk-playdarapi and libtomahawk-widgets in their own packages
- Update desktop database and icon theme cache on application
  (un)installation (instead of library)
- Not building/packaging the crash reporter right now because we
  can't upload debug symbols from the OBS
- Updated dependencies:
  * clucene was replaced by lucene++
  * require qtkeychain to store passwords in gnome keyring or kwallet
  * require sparsehash to store certain cloud files partially in memory
  * require websocketpp for hatchet plugin
  * require telepathy-qt4 for the optional telepathy integration
  * require kde for the optional kde configuration for the telepathy
    integration
- Rename _libtomahawk_soname variable to _libtomahawk_soversion in
  spec file
- Remove tomahawk-nobreakpad.patch because it was upstreamed
- Remove tomahawk-0.7.0-build-portfwd-statically-and-rename-libtomahawklib-to-libtomahawk.diff:
  Patch was taken from upstream and is part of this release
* Fri Aug  1 2014 dvlaeev@suse.com
- Disable breakpad and crashreported on ppc64le as well
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Smaller cleanup of phonon Requires/Conflicts/etc - don't make
  Tomahawk require phonon as that package exists only via provides.
  Also separete backend conflicts and recommends to separate lines
* Tue Jun  4 2013 dvaleev@suse.com
- drop tomahawk-ppc64.path. Fix original issue instead
  (tomahawk-nobreakpad.spec). With this patch BreakPad header is
  not included id NOBREAKPAD was requested.
  Fixes TWK-1248
* Thu May 16 2013 dev@dominik-schmidt.de
- Add version to tomahawk-kde requires tomahawk
* Fri May 10 2013 dev@dominik-schmidt.de
- Require the plugins instead of only recommending them
* Wed May  8 2013 dev@dominik-schmidt.de
- Split main package into application, library and plugins packages
  * Add tomahawk-0.7.0-build-portfwd-statically-and-rename-libtomahawklib-to-libtomahawk.diff:
    Patch combines three commits from upstream master and can be
    removed for 0.8.x. Without it there's an unversioned .so that
    is needed by the main library. The main library also has a
    wrong soname and filename for calling the package libtomahawk
* Sun May  5 2013 dev@dominik-schmidt.de
- Version 0.7.0
  * JavaScript Resolvers can now expose collections.
  * Introduced bundle system for JavaScript Resolvers, called "axes".
  * Fixed playback-loop caused by duplicate tracks in a playlist.
  * Improved peer handling.
  * Taking an account offline now also disconnects associated peers.
  * Improved spotify protocol handling.
  * Added "Append to Playlist" context menu item.
  * User-friendlier collection handling: added info-buttons for artists and
    albums. Double-clicking an item expands it now.
  * Charts only load on-demand now.
  * Fixed Diagnostics information not correctly updating.
  * Fixed issue with hidden sidebar and panels.
  * Fixed issues with some color schemes.
  * Fixed playing files with special characters in the filename.
  * Improved stability.
  * Added translations for Catalan, Czech, Galician, Greek, Italian and
    Chinese.
  * (Windows) Smoother and more responsive audio playback.
  * (Linux) Fixed grid issues with GTK-styles.
* Mon Jan 28 2013 meissner@suse.com
- tomahawk-ppc64.patch: fixed ppc64 build hopefully
* Fri Jan 18 2013 dev@dominik-schmidt.de
- Version 0.6.0:
  * Smoother scrolling in account configuration on KDE/Oxygen
  * Fixed a few potential crashes
* Wed Jan  9 2013 dev@dominik-schmidt.de
- Version 0.6.0beta1
  * Improved icon theme with vector graphics.
  * Higher resolution artist and album images.
  * You can now click artists, albums and tracks mentioned in artists'
    biographies.
  * New AudioControl logic - only enable Prev/Skip buttons if available.
  * Added more options to right-click/context menus.
  * Resolver source icon in Audiocontrols now supports being a link-back URL
    to original source.
  * Make friends' currently playing song (in sidebar) clickable.
  * Improve MusicBrainz plugin to use normalized artist names and avoid
    duplicate tracks.
  * Access Control queries now stay on the bottom of the job view, removing
    the tendency to jump away from the mouse.
  * Improved random mode, preventing songs from being played in too rapid
    succession.
  * You can now choose between various view modes for your playlists.
  * Nicer layout for the Artist, Album & Track pages.
  * Follow HTTP redirects when fetching Playlists.
  * Main menu can now be hidden and instead be shown as a toolbar button.
  * Connectivity controls in the toolbar.
  * Cleaned up settings dialog.
  * Ability to sync Spotify Starred Tracks with Tomahawk's Loved Tracks.
  * Remove YouTube resolver from plug-in directory on request of YouTube.
  * Fixed iTunes m3u playlist support.
  * Support dropping of new Soundcloud user, track, set & likes URLs.
  * Added HotNewHipHop as available chart.
  * Added iTunes as available source for New Releases.
  * Updates and additions to translations including: Japanese, Bulgarian,
    Finnish, Russian, Arabic, Chinese, Swedish, Czech and more.
  * (Linux) Allow disabling of playback notifications.
* Tue Dec 18 2012 dev@dominik-schmidt.de
- when breakpad is disabled, also disable the crash reporter
* Tue Dec 18 2012 dvaleev@suse.com
- don't build breakpad for ppc. (minidump is not implemented here)
* Thu Nov 15 2012 dev@dominik-schmidt.de
- workaround regression in CMake 2.8.10 that makes Tomahawk
  fail to link (cf. http://www.cmake.org/Bug/view.php?id=13646 )
* Wed Nov 14 2012 dev@dominik-schmidt.de
- fix Supplements: for tomahawk-kde
- Make tomahawk-kde require tomahawk itself
  (pointless installing a .khotkeys file without the application)
- remove obsolete %%clean section
- install ChangeLog, README, AUTHORS and LICENSE.txt
- add rpmlint filter to surpress warning about libqt4-sql-sqlite
  requirement
* Fri Sep 28 2012 dev@dominik-schmidt.de
- remove the crash reporter in the file list for %%arm, it's not
  built there - i'll investigate why it's disabled
* Mon Sep 17 2012 dev@dominik-schmidt.de
- use %%icon_theme_cache_post(un)
- add libqt4-sql-sqlite as runtime dependency
* Thu Sep  6 2012 dev@dominik-schmidt.de
- liblastfm-devel was updated to liblastfm1, so no more
  liblasstm1-devel package anymore
* Thu Aug 23 2012 dev@dominik-schmidt.de
- Version 0.5.5
  * new icon
  * support .aiff
  * support syncing playlists with spotify
  * improved proxy support
  * lots of ui improvements
  * support importing last.fm history
* Mon Apr  9 2012 dev@dominik-schmidt.de
- Version 0.4.2
  * Resuming playback restores correct volume settings.
  * Reduced CPU usage during playback.
* Thu Apr  5 2012 dev@dominik-schmidt.de
- Version 0.4.1
  * Fixed various crashes.
  * Fixed issues with auto-updating XSPF playlists.
  * Double-clicking a playlist starts playing it.
  * Resolvers can now return disc number and album position for results.
  * Fixed sorting playlists by track number.
  * Fixed issues with changing proxy.
  * Fixed Twitter authentication issues.
- drop patch that is part of the release
* Sun Mar 18 2012 dev@dominik-schmidt.de
- fix build with QTweetLib 0.5
- restart a failed build with a single make job so the error
  is easier to spot
* Wed Mar  7 2012 dev@dominik-schmidt.de
- Version 0.4.0
  * Added visual notification for database indexing job.
  * Fixed icons not appearing in resolvers list.
  * Fixed various UI glitches and stray error messages in stations.
  * Fixed bug where album page would resolve bottom-to-top.
  * Fixed bug where Footnotes would not update when changing selected album in Album View.
  * Fixed dragging albums and artists from charts, album, and artist views.
  * Fixed bug where filter text would be one step behind filter value.
  * Fixed bug where resolvers would enable themselves after auto-updating.
  * Fixed occasional crash when dropping tracks onto New Station item.
  * Added jump-to-current-track support for search results page.
  * Fixed out of sync Show/Hide menu items on OS X when hidden with cmd-h.
  * Fixed non-resolving tracks when dragging from album view.
  * Fixed /Volumes directory not showing up on OS X.
  * Fixed fetching album covers for albums with special characters.
  * Show errors and continue gracefully when resolved audio is not available.
  * Fixed various crashes on exit.
  * Added basic command-line options for playback control.
  * Bumped up web api timeouts to allow web clients to finish resolving.
  * Added filename suggestion when exporting a playlist.
  * Cleaned up highlighting of artist names in album view.
  * Cleaned up alignment of playlist items.
  * Fixed potential crash when searching.
  * Added support for disc number.
  * Added SoundCloudWall.com charts.
  * Added ability to "lock on" to a user when listening along, to skip along.
  * Fixed bug where loved tracks would be refreshed much too often.
  * Fixed startup crash on OS X.
  * Fixed some font size issues.
  * Sped up Tomahawk startup by moving chart loading into a separate thread.
  * Added support for parsing Grooveshark and Tinysong tracks and playlists.
  * Reorganized sidebar to follow more logical item groupings.
  * Added artist and album results to global searches.
  * Fixed style and contrast issues when using GTK styles.
  * Fixed paths to artwork when using MPRIS2 interface.
* Mon Jan  9 2012 dev@dominik-schmidt.de
- Add tomahawk-kde package for optional KDE integration
  * makes multimedia keys configurable from systemsettings
- use rpm macros more consistently
- update formatting
* Tue Dec 13 2011 dev@dominik-schmidt.de
- Update firewall filename and description
* Wed Dec  7 2011 dev@dominik-schmidt.de
- Version 0.3.3
  * Automatically load Super Collection tracks when no official release
    information is available.
  * Fixed stations not fetching new tracks under certain circumstances.
  * Fixed Footnotes not always updating when selecting a new track.
  * Added support for ow.ly, fb.me, itun.es and tinyurl.com URL shorteners.
  * Fixed invisible sidebar items on Linux.
  * Fixed tomahawk:// links cross desktop.
- fix version string and run format_spec_file
* Thu Nov 10 2011 dev@dominik-schmidt.de
- version bump to 0.3.0-
* Sat Sep  3 2011 julian@svg4all.de
- version bump to 0.2.3
- build in release mode
* Sun Mar 20 2011 dev@dominik-schmidt.de
-  Initial version: 0.0.1rc1
